@@ -1,7 +1,7 @@
 export ROOT_DIR="$$PWD"
 
-#wget "https://github.com/RWTHmediTEC/Carna/archive/refs/tags/$VERSION_CARNA.tar.gz" -O carna.tgz
-wget "http://localhost/3.0.2-p1.tar.gz" -O carna.tgz
+wget "https://github.com/kostrykin/Carna/archive/refs/tags/$VERSION_CARNA.tar.gz" -O carna.tgz
+#wget "http://localhost/3.0.2-p1.tar.gz" -O carna.tgz
 tar -vzxf carna.tgz
 cd "Carna-$VERSION_CARNA"
 mkdir -p build/make_release
