@@ -4,17 +4,9 @@ export ROOT_DIR="$PWD"
 wget "http://localhost/3.0.2-p1.tar.gz" -O carna.tgz
 tar -vzxf carna.tgz
 cd "Carna-3.0.2"
-
-#mkdir -p build/make_debug
 mkdir -p build/make_release
-
-#cd "$ROOT_DIR/Carna-3.0.2/build/make_debug"
-#cmake -DCMAKE_BUILD_TYPE=Debug -DBUILD_DOC=OFF -DBUILD_TEST=ON -DBUILD_DEMO=OFF ../.. -DCMAKE_INSTALL_PREFIX=$PREFIX -DCMAKE_PREFIX_PATH=$PREFIX
-#make VERBOSE=1
-#make install
-
 cd "$ROOT_DIR/Carna-3.0.2/build/make_release"
-cmake -DCMAKE_BUILD_TYPE=Release -DBUILD_DOC=OFF -DBUILD_TEST=ON -DBUILD_DEMO=OFF ../.. -DCMAKE_INSTALL_PREFIX=$PREFIX -DCMAKE_PREFIX_PATH=$PREFIX
+cmake -DCMAKE_BUILD_TYPE=Release -DBUILD_DOC=OFF -DBUILD_TEST=ON -DBUILD_DEMO=OFF -DCMAKE_INSTALL_PREFIX=$PREFIX -DCMAKE_PREFIX_PATH=$PREFIX -DBUILD_EGL=ON ../..
 make VERBOSE=1
 make install
 
